abacusai.model_upload — AbacusAI documentation

# abacusai.model_upload

## Classes

`ModelUpload` | A model version that includes the upload identifiers for the various required files.

## Module Contents

class abacusai.model_upload.ModelUpload(client, modelId=None, modelVersion=None, status=None, createdAt=None, modelUploadId=None, embeddingsUploadId=None, artifactsUploadId=None, verificationsUploadId=None, defaultItemsUploadId=None, modelFileUploadId=None, modelStateUploadId=None, inputPreprocessorUploadId=None, requirementsUploadId=None, resourcesUploadId=None, multiCatalogEmbeddingsUploadId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A model version that includes the upload identifiers for the various required files.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - modelId (str) – A reference to the model this version belongs to.

    - modelVersion (str) – A unique identifier for the model version.

    - status (str) – The current status of the model.

    - createdAt (str) – The timestamp at which the model version was created, in ISO-8601 format.

    - modelUploadId (str) – An upload identifier to be used when uploading the TensorFlow Saved Model.

    - embeddingsUploadId (str) – An upload identifier to be used when uploading the embeddings CSV.

    - artifactsUploadId (str) – An upload identifier to be used when uploading the artifacts JSON file.

    - verificationsUploadId (str) – An upload identifier to be used when uploading the verifications JSON file.

    - defaultItemsUploadId (str) – An upload identifier to be used when uploading the default items JSON file.

    - modelFileUploadId (str) – An upload identifier to be used when uploading the model JSON file.

    - modelStateUploadId (str) – An upload identifier to be used when uploading the model state JSON file.

    - inputPreprocessorUploadId (str) – An upload identifier to be used when uploading the input preprocessor JSON file.

    - requirementsUploadId (str) – An upload identifier to be used when uploading the requirements JSON file.

    - resourcesUploadId (str) – An upload identifier to be used when uploading the resources JSON file.

    - multiCatalogEmbeddingsUploadId (str) – An upload identifier to be used when upload the multi-catalog embeddings CSV file.

  model_id = None
  model_version = None
  status = None
  created_at = None
  model_upload_id = None
  embeddings_upload_id = None
  artifacts_upload_id = None
  verifications_upload_id = None
  default_items_upload_id = None
  model_file_upload_id = None
  model_state_upload_id = None
  input_preprocessor_upload_id = None
  requirements_upload_id = None
  resources_upload_id = None
  multi_catalog_embeddings_upload_id = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict